@@ -1,14 +1,23 @@
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
+
 """Application base class for displaying data about a single object.
 """
 import abc
 
-import six
-
-from .display import DisplayCommandBase
+from . import display
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ShowOne(DisplayCommandBase):
+class ShowOne(display.DisplayCommandBase, metaclass=abc.ABCMeta):
     """Command base class for displaying data about a single object.
     """
 
